@@ -46,20 +46,23 @@ def history_email_for(instance, title):
         "title": title,
     }
 
-    body = _(
-        """Updated on %(history_date)s
+    body = (
+        _(
+            """Updated on %(history_date)s
 Updated by %(username)s
 
 %(diff)s
 
 For more information:
 %(instance_url)s"""
-    ) % {
-        "history_date": history.history_date.strftime("%c"),
-        "username": getattr(history.history_user, "username", ""),
-        "diff": history.history_change_reason,
-        "instance_url": instance.get_full_url(),
-    }
+        )
+        % {
+            "history_date": history.history_date.strftime("%c"),
+            "username": getattr(history.history_user, "username", ""),
+            "diff": history.history_change_reason,
+            "instance_url": instance.get_full_url(),
+        }
+    )
     return subject, body
 
 
@@ -118,7 +121,7 @@ class ReadOnlyHistoryAdmin(SimpleHistoryAdmin):
     history_list_display = ["Diff"]
 
     def Diff(self, obj):  # pylint: disable=invalid-name
-        return safe("<pre>%s</pre>" % obj.history_change_reason)
+        return safe(f"<pre>{obj.history_change_reason}</pre>")
 
     def get_readonly_fields(self, request, obj=None):
         # make all fields readonly
