@@ -27,10 +27,8 @@ from tcms.testplans.models import TestPlan
 from tcms.testruns.models import TestRun
 
 
-@method_decorator(
-    login_required, name="dispatch"
-)  # pylint: disable=missing-permission-required
-class DashboardView(TemplateView):
+@method_decorator(login_required, name="dispatch")
+class DashboardView(TemplateView):  # pylint: disable=missing-permission-required
 
     template_name = "dashboard.html"
 
