@@ -34,9 +34,14 @@ class JIRA(IssueTrackerType):
     """
     Support for JIRA. Requires:
 
-    :base_url: - the URL of this JIRA instance
-    :api_username: - a username registered in JIRA
-    :api_password: - the password for this username
+    :base_url: the URL of this JIRA instance. For example https://kiwitcms.atlassian.net
+    :api_username: a username registered in JIRA
+    :api_password: API token for this username, see
+                   https://id.atlassian.com/manage-profile/security/api-tokens
+
+    .. important::
+
+        The field ``API URL`` is not used for Jira integration and can be left blank!
 
     Additional control can be applied via the ``JIRA_OPTIONS`` configuration
     setting (in ``product.py``). By default this setting is not provided and
@@ -68,7 +73,8 @@ class JIRA(IssueTrackerType):
     def bug_id_from_url(cls, url):
         """
         Jira IDs are the last group of chars at the end of the URL.
-        For example https://issues.jenkins-ci.org/browse/JENKINS-31044
+        For example https://issues.jenkins-ci.org/browse/JENKINS-31044 will
+        return an ID of JENKINS-31044
         """
         return url.strip().split("/")[-1]
 
@@ -107,7 +113,7 @@ class JIRA(IssueTrackerType):
             new_issue = self.rpc.create_issue(
                 project=project.id,
                 issuetype={"name": issue_type.name},
-                summary="Failed test: %s" % execution.case.summary,
+                summary=f"Failed test: {execution.case.summary}",
                 description=self._report_comment(execution),
             )
             new_url = self.bug_system.base_url + "/browse/" + new_issue.key
@@ -126,7 +132,7 @@ class JIRA(IssueTrackerType):
         args = {
             "pid": project.id,
             "issuetype": issue_type.id,
-            "summary": "Failed test: %s" % execution.case.summary,
+            "summary": f"Failed test: {execution.case.summary}",
             "description": self._report_comment(execution),
         }
 
@@ -141,9 +147,8 @@ class GitHub(IssueTrackerType):
     """
     Support for GitHub. Requires:
 
-    :base_url: - URL to a GitHub repository for which we're going to report issues
-    :api_password: - GitHub API token - needs ``repo`` or ``public_repo``
-                     permissions.
+    :base_url: URL to a GitHub repository for which we're going to report issues
+    :api_password: GitHub API token - needs ``repo`` or ``public_repo`` permissions
 
     .. note::
 
@@ -165,7 +170,7 @@ class GitHub(IssueTrackerType):
         GitHub only supports title and body parameters
         """
         args = {
-            "title": "Failed test: %s" % execution.case.summary,
+            "title": f"Failed test: {execution.case.summary}",
             "body": self._report_comment(execution),
         }
 
@@ -207,11 +212,13 @@ class GitHub(IssueTrackerType):
 
 class Gitlab(IssueTrackerType):
     """
-    Support for Gitlab. Requires:
+    Support for GitLab. Requires:
 
-    :base_url: URL to a GitLab repository for which we're going to report issues
-    :api_url: URL to GitLab instance. Usually gitlab.com!
-    :api_password: GitLab API token.
+    :base_url: URL to a GitLab repository for which we're going to report issues.
+               For example https://gitlab.com/kiwitcms/integration-testing
+    :api_url: URL to a GitLab instance. For example https://gitlab.com
+    :api_password: GitLab API token with the ``api`` scope. See
+                   https://gitlab.com/-/profile/personal_access_tokens
 
     .. note::
 
@@ -235,7 +242,7 @@ class Gitlab(IssueTrackerType):
         project = self.rpc.projects.get(repo_id)
         new_issue = project.issues.create(
             {
-                "title": "Failed test: %s" % execution.case.summary,
+                "title": f"Failed test: {execution.case.summary}",
                 "description": self._report_comment(execution),
             }
         )
@@ -266,9 +273,9 @@ class Redmine(IssueTrackerType):
     """
     Support for Redmine. Requires:
 
-    :base_url: - the URL for this Redmine instance
-    :api_username: - a username registered in Redmine
-    :api_password: - the password for this username
+    :base_url: the URL for this Redmine instance. For example http://redmine.example.org:3000
+    :api_username: a username registered in Redmine
+    :api_password: the password for this username
     """
 
     it_class = redmine_integration.RedmineThread
@@ -343,14 +350,14 @@ class Redmine(IssueTrackerType):
         priority = self.redmine_priority_by_name(execution.case.priority.value)
 
         new_issue = self.rpc.issue.create(
-            subject="Failed test: %s" % execution.case.summary,
+            subject=f"Failed test: {execution.case.summary}",
             description=self._report_comment(execution),
             project_id=project.id,
             tracker_id=tracker.id,
             status_id=status.id,
             priority_id=priority.id,
         )
-        new_url = self.bug_system.base_url + "/issues/%d" % new_issue.id
+        new_url = f"{self.bug_system.base_url}/issues/{new_issue.id}"
 
         # and also add a link reference that will be shown in the UI
         LinkReference.objects.get_or_create(
