@@ -8,10 +8,11 @@ from modernrpc.core import REQUEST_KEY, rpc_method
 from tcms.core.contrib.linkreference.models import LinkReference
 from tcms.core.helpers import comments
 from tcms.core.utils import form_errors_to_list
+from tcms.rpc.api.forms.testexecution import LinkReferenceForm
 from tcms.rpc.api.forms.testrun import UpdateExecutionForm
 from tcms.rpc.api.utils import tracker_from_url
 from tcms.rpc.decorators import permissions_required
-from tcms.testruns.models import TestExecution
+from tcms.testruns.models import TestExecution, TestExecutionProperty
 
 # conditional import b/c this App can be disabled
 if "tcms.bugs.apps.AppConfig" in settings.INSTALLED_APPS:
@@ -31,6 +32,7 @@ __all__ = (
     "add_link",
     "get_links",
     "remove_link",
+    "properties",
 )
 
 
@@ -46,7 +48,7 @@ def add_comment(execution_id, comment, **kwargs):
         :type execution_id: int
         :param comment: The text to add as a comment
         :type comment: str
-        :param kwargs: Dict providing access to the current request, protocol
+        :param \\**kwargs: Dict providing access to the current request, protocol,
                 entry point name and handler instance from the rpc method
         :return: Serialized :class:`django_comments.models.Comment` object
         :rtype: dict
@@ -176,7 +178,7 @@ def update(execution_id, values, **kwargs):
         :type execution_id: int
         :param values: Field values for :class:`tcms.testruns.models.TestExecution`
         :type values: dict
-        :param kwargs: Dict providing access to the current request, protocol
+        :param \\**kwargs: Dict providing access to the current request, protocol,
                 entry point name and handler instance from the rpc method
         :return: Serialized :class:`tcms.testruns.models.TestExecution` object
         :rtype: dict
@@ -251,19 +253,30 @@ def add_link(values, update_tracker=False, **kwargs):
         :param update_tracker: Automatically update Issue Tracker by placing a comment
                                linking back to the failed TestExecution.
         :type update_tracker: bool, default=False
-        :param kwargs: Dict providing access to the current request, protocol
+        :param \\**kwargs: Dict providing access to the current request, protocol,
                 entry point name and handler instance from the rpc method
         :return: Serialized
                  :class:`tcms.core.contrib.linkreference.models.LinkReference` object
         :rtype: dict
         :raises RuntimeError: if operation not successfull
+        :raises ValueError: if input validation fails
 
         .. note::
 
             Always 'link' with IT instance if URL is from Kiwi TCMS own bug tracker!
     """
-    link, _ = LinkReference.objects.get_or_create(**values)
-    response = model_to_dict(link)
+    # for backwards compatibility
+    if "execution_id" in values:
+        values["execution"] = values["execution_id"]
+        del values["execution_id"]
+
+    form = LinkReferenceForm(values)
+
+    if form.is_valid():
+        link = form.save()
+    else:
+        raise ValueError(form_errors_to_list(form))
+
     request = kwargs.get(REQUEST_KEY)
     tracker = tracker_from_url(link.url, request)
 
@@ -275,7 +288,7 @@ def add_link(values, update_tracker=False, **kwargs):
     ) or isinstance(tracker, KiwiTCMS):
         tracker.add_testexecution_to_issue([link.execution], link.url)
 
-    return response
+    return model_to_dict(link)
 
 
 @permissions_required("linkreference.delete_linkreference")
@@ -318,3 +331,28 @@ def get_links(query):
             "is_defect",
         )
     )
+
+
+@permissions_required("testruns.view_testexecutionproperty")
+@rpc_method(name="TestExecution.properties")
+def properties(query):
+    """
+    .. function:: RPC TestExecution.properties(query)
+
+        Return properties for a TestExecution
+
+        :param query: Field lookups for
+                      :class:`tcms.testruns.models.TestExecutionProperty`
+        :type query: dict
+        :return: Serialized list of :class:`tcms.testruns.models.TestExecutionProperty`
+                 objects
+        :rtype: dict
+    """
+    return list(
+        TestExecutionProperty.objects.filter(**query).values(
+            "id",
+            "name",
+            "value",
+            "execution",
+        )
+    )
