@@ -8,7 +8,7 @@ from tcms.rpc.api.forms.testrun import UpdateForm, UserForm
 from tcms.rpc.decorators import permissions_required
 from tcms.testcases.models import TestCase
 from tcms.testruns.forms import NewRunForm
-from tcms.testruns.models import TestExecution, TestRun
+from tcms.testruns.models import Property, TestExecution, TestRun
 
 __all__ = (
     "create",
@@ -21,6 +21,7 @@ __all__ = (
     "remove_tag",
     "add_cc",
     "remove_cc",
+    "properties",
 )
 
 
@@ -36,8 +37,8 @@ def add_case(run_id, case_id):
         :type run_id: int
         :param case_id: PK of TestCase to be added
         :type case_id: int
-        :return: Serialized :class:`tcms.testruns.models.TestExecution` object
-        :rtype: dict
+        :return: A list of serialized :class:`tcms.testruns.models.TestExecution` objects
+        :rtype: list(dict)
         :raises DoesNotExist: if objects specified by the PKs don't exist
         :raises PermissionDenied: if missing *testruns.add_testexecution* permission
         :raises RuntimeError: if test case status is not CONFIRMED
@@ -46,10 +47,10 @@ def add_case(run_id, case_id):
     case = TestCase.objects.get(pk=case_id)
 
     if run.executions.filter(case=case).exists():
-        return model_to_dict(run.executions.filter(case=case).first())
+        return annotate_executions_with_properties(run.executions.filter(case=case))
 
     if not case.case_status.is_confirmed:
-        raise RuntimeError("TC-%d status is not confirmed" % case.pk)
+        raise RuntimeError(f"TC-{case.pk} status is not confirmed")
 
     # always add new TEs at the end of TR
     sortkey = 10
@@ -57,8 +58,22 @@ def add_case(run_id, case_id):
     if last_te:  # in case there are no other TEs
         sortkey += last_te.sortkey
 
-    execution = run.create_execution(case=case, sortkey=sortkey)
-    return model_to_dict(execution)
+    return annotate_executions_with_properties(
+        run.create_execution(case=case, sortkey=sortkey)
+    )
+
+
+def annotate_executions_with_properties(executions_iterable):
+    result = []
+
+    for execution in executions_iterable:
+        serialized_execution = model_to_dict(execution)
+        serialized_execution["properties"] = list(
+            execution.properties().values("name", "value")
+        )
+        result.append(serialized_execution)
+
+    return result
 
 
 @permissions_required("testruns.delete_testexecution")
@@ -116,7 +131,7 @@ def get_cases(run_id):
     executions = TestExecution.objects.filter(run_id=run_id).values(
         "case", "pk", "status__name"
     )
-    extra_info = dict(((row["case"], row) for row in executions.iterator()))
+    extra_info = {row["case"]: row for row in executions.iterator()}
 
     for case in result:
         info = extra_info[case["id"]]
@@ -138,7 +153,7 @@ def add_tag(run_id, tag_name, **kwargs):
         :type run_id: int
         :param tag_name: Tag name to add
         :type tag_name: str
-        :param kwargs: Dict providing access to the current request, protocol
+        :param \\**kwargs: Dict providing access to the current request, protocol,
                 entry point name and handler instance from the rpc method
         :return: Serialized list of :class:`tcms.management.models.Tag` objects
         :rtype: dict
@@ -236,8 +251,8 @@ def filter(query=None):  # pylint: disable=redefined-builtin
         TestRun.objects.filter(**query)
         .values(
             "id",
-            "product_version",
-            "product_version__value",
+            "plan__product_version",
+            "plan__product_version__value",
             "start_date",
             "stop_date",
             "planned_start",
@@ -344,3 +359,33 @@ def remove_cc(run_id, username):
         raise ValueError(form_errors_to_list(form))
 
     test_run.remove_cc(form.cleaned_data["user"])
+
+
+@permissions_required("testruns.view_property")
+@rpc_method(name="TestRun.properties")
+def properties(query=None):
+    """
+    .. function:: TestRun.properties(query)
+
+        Return all properties for the specified test run(s).
+
+        :param query: Field lookups for :class:`tcms.testruns.models.Property`
+        :type query: dict
+        :return: Serialized list of :class:`tcms.testruns.models.Property` objects.
+        :rtype: list(dict)
+        :raises PermissionDenied: if missing *testruns.view_property* permission
+    """
+    if query is None:
+        query = {}
+
+    return list(
+        Property.objects.filter(**query)
+        .values(
+            "id",
+            "run",
+            "name",
+            "value",
+        )
+        .order_by("run", "name", "value")
+        .distinct()
+    )
