@@ -3,12 +3,12 @@ from django.forms import EmailField, ValidationError
 
 
 class MultipleEmailField(EmailField):
-    """ Holding mulitple email addresses """
+    """Holding mulitple email addresses"""
 
     delimiter = ","
 
     default_error_messages = {
-        "invalid": u"%(value)s is/are not valid email addresse(s).",
+        "invalid": "%(value)s is/are not valid email addresse(s).",
     }
 
     def to_python(self, value):
@@ -16,7 +16,7 @@ class MultipleEmailField(EmailField):
             return []
 
         if not isinstance(value, str):
-            raise ValidationError("%s is not a valid string value." % str(value))
+            raise ValidationError(f"'{value}' is not a valid string value.")
 
         result = []
 
