@@ -18,14 +18,13 @@ def get_plan_notification_recipients(plan):  # pylint: disable=invalid-name
         recipients.add(plan.author.email)
 
     if plan.emailing.auto_to_case_owner:
-        case_authors = plan.case.values_list('author__email', flat=True)
+        case_authors = plan.cases.values_list("author__email", flat=True)
         recipients.update(case_authors)  # pylint: disable=objects-update-used
 
     if plan.emailing.auto_to_case_default_tester:
-        case_testers = plan.case.values_list('default_tester__email',
-                                             flat=True)
+        case_testers = plan.cases.values_list("default_tester__email", flat=True)
         recipients.update(case_testers)  # pylint: disable=objects-update-used
 
     # don't email author of last change
-    recipients.discard(getattr(plan.history.latest().history_user, 'email', ''))
+    recipients.discard(getattr(plan.history.latest().history_user, "email", ""))
     return list(filter(bool, recipients))
