@@ -1,6 +1,5 @@
 # -*- coding: utf-8 -*-
 
-from django.contrib import messages
 from django.contrib.auth import get_user_model
 from django.contrib.auth.decorators import permission_required
 from django.core.exceptions import ObjectDoesNotExist
@@ -19,7 +18,12 @@ from tcms.core.forms import SimpleCommentForm
 from tcms.testcases.models import BugSystem, TestCase, TestCasePlan, TestCaseStatus
 from tcms.testplans.models import TestPlan
 from tcms.testruns.forms import NewRunForm, SearchRunForm
-from tcms.testruns.models import TestExecutionStatus, TestRun
+from tcms.testruns.models import (
+    Environment,
+    EnvironmentProperty,
+    TestExecutionStatus,
+    TestRun,
+)
 
 User = get_user_model()  # pylint: disable=invalid-name
 
@@ -33,43 +37,30 @@ class NewTestRunView(View):
 
     def get(self, request, form_initial=None, is_cloning=False):
         plan_id = request.GET.get("p")
-        if not plan_id:
-            messages.add_message(
-                request,
-                messages.ERROR,
-                _("Creating a TestRun requires a TestPlan, select one"),
-            )
-            return HttpResponseRedirect(reverse("plans-search"))
-
-        if not request.GET.get("c"):
-            messages.add_message(
-                request,
-                messages.ERROR,
-                _("Creating a TestRun requires at least one TestCase"),
-            )
-            return HttpResponseRedirect(reverse("test_plan_url_short", args=[plan_id]))
-
-        test_cases = TestCase.objects.filter(pk__in=request.GET.getlist("c"))
 
         # note: ordered by pk for test_show_create_new_run_page()
-        tcs_values = test_cases.select_related(
-            "author", "case_status", "category", "priority"
-        ).order_by("pk")
+        test_cases = (
+            TestCase.objects.filter(pk__in=request.GET.getlist("c"))
+            .select_related("author", "case_status", "category", "priority")
+            .order_by("pk")
+        )
 
-        test_plan = TestPlan.objects.get(pk=plan_id)
+        test_plan = TestPlan.objects.filter(pk=plan_id).first()
         if not form_initial:
             form_initial = {
-                "summary": "Test run for %s" % test_plan.name,
-                "manager": test_plan.author.email,
+                "summary": f"Test run for {test_plan.name}" if test_plan else "",
+                "manager": test_plan.author.email if test_plan else "",
                 "default_tester": request.user.email,
                 "notes": "",
                 "plan": plan_id,
             }
+
         form = NewRunForm(initial=form_initial)
         form.populate(plan_id)
 
         context_data = {
-            "test_cases": tcs_values,
+            "plan_id": plan_id,  # used for UI conditionals
+            "test_cases": test_cases,
             "form": form,
             "disabled_cases": get_disabled_test_cases_count(test_cases),
             "is_cloning": is_cloning,
@@ -82,6 +73,13 @@ class NewTestRunView(View):
 
         if form.is_valid():
             test_run = form.save()
+
+            # copy all of the selected properties into the test run
+            for prop in EnvironmentProperty.objects.filter(
+                environment__in=form.cleaned_data["environment"]
+            ):
+                test_run.property_set.create(name=prop.name, value=prop.value)
+
             loop = 1
 
             for case in form.cleaned_data["case"]:
@@ -95,8 +93,9 @@ class NewTestRunView(View):
 
                 test_run.create_execution(
                     case=case,
-                    sortkey=sortkey,
                     assignee=form.cleaned_data["default_tester"],
+                    sortkey=sortkey,
+                    matrix_type=form.cleaned_data["matrix_type"],
                 )
                 loop += 1
 
@@ -109,13 +108,15 @@ class NewTestRunView(View):
                 )
             )
 
-        test_cases = TestCase.objects.filter(pk__in=request.POST.getlist("case"))
+        test_cases = (
+            TestCase.objects.filter(pk__in=request.POST.getlist("case"))
+            .select_related("author", "case_status", "category", "priority")
+            .order_by("pk")
+        )
 
-        tcs_values = test_cases.select_related(
-            "author", "case_status", "category", "priority"
-        ).order_by("pk")
         context_data = {
-            "test_cases": tcs_values,
+            "plan_id": request.POST.get("plan"),
+            "test_cases": test_cases,
             "form": form,
             "disabled_cases": get_disabled_test_cases_count(test_cases),
         }
@@ -172,7 +173,7 @@ class GetTestRunView(DetailView):
                     ),
                     (
                         _("History"),
-                        "/admin/testruns/testrun/%d/history/" % self.object.pk,
+                        f"/admin/testruns/testrun/{self.object.pk}/history/",
                     ),
                     ("-", "-"),
                     (
@@ -214,6 +215,11 @@ class EditTestRunView(UpdateView):
 
         return form
 
+    def get_context_data(self, **kwargs):
+        context = super().get_context_data(**kwargs)
+        context["plan_id"] = self.object.plan
+        return context
+
     def get_initial(self):
         return {
             "manager": self.object.manager,
@@ -250,3 +256,50 @@ class CloneTestRunView(NewTestRunView):
 
 def get_disabled_test_cases_count(test_cases):
     return test_cases.filter(case_status__is_confirmed=False).count()
+
+
+@method_decorator(
+    object_permission_required(
+        "testruns.view_environment", (Environment, "pk", "pk"), accept_global_perms=True
+    ),
+    name="dispatch",
+)
+class GetEnvironment(DetailView):
+    template_name = "testruns/environment.html"
+    http_method_names = ["get"]
+    model = Environment
+
+    def get_context_data(self, **kwargs):
+        context = super().get_context_data(**kwargs)
+        context["OBJECT_MENU_ITEMS"] = [
+            (
+                "...",
+                [
+                    (
+                        _("Edit"),
+                        reverse(
+                            "admin:testruns_environment_change",
+                            args=[self.object.pk],
+                        ),
+                    ),
+                    ("-", "-"),
+                    (
+                        _("Object permissions"),
+                        reverse(
+                            "admin:testruns_environment_permissions",
+                            args=[self.object.pk],
+                        ),
+                    ),
+                    ("-", "-"),
+                    (
+                        _("Delete"),
+                        reverse(
+                            "admin:testruns_environment_delete",
+                            args=[self.object.pk],
+                        ),
+                    ),
+                ],
+            )
+        ]
+
+        return context
